<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>OpenOrienteering::AutosaveDialog</name>
    <message numerus="yes">
        <location filename="../src/gui/autosave_dialog.cpp" line="48"/>
        <location filename="../src/gui/autosave_dialog.cpp" line="54"/>
        <source>%n bytes</source>
        <translation>
            <numerusform>%n byte</numerusform>
            <numerusform>%n bytes</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OpenOrienteering::Importer</name>
    <message numerus="yes">
        <location filename="../src/fileformats/file_import_export.cpp" line="201"/>
        <source>Dropped %n irregular object(s).</source>
        <translation>
            <numerusform>Dropped one irregular object.</numerusform>
            <numerusform>Dropped %n irregular objects.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OpenOrienteering::MapEditorController</name>
    <message numerus="yes">
        <location filename="../src/gui/map/map_editor.cpp" line="1888"/>
        <source>Cut %n object(s)</source>
        <extracomment>Past tense. Displayed when an Edit &gt; Cut operation is completed.</extracomment>
        <translation>
            <numerusform>Cut one object</numerusform>
            <numerusform>Cut %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/gui/map/map_editor.cpp" line="1940"/>
        <source>Copied %n object(s)</source>
        <translation>
            <numerusform>Copied one object</numerusform>
            <numerusform>Copied %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/gui/map/map_editor.cpp" line="1980"/>
        <source>Pasted %n object(s)</source>
        <translation>
            <numerusform>Pasted one object</numerusform>
            <numerusform>Pasted %n objects</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/gui/map/map_editor.cpp" line="2791"/>
        <source>Duplicated %n object(s)</source>
        <translation>
            <numerusform>Duplicated one object</numerusform>
            <numerusform>Duplicated %n objects</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OpenOrienteering::OgrFileImport</name>
    <message numerus="yes">
        <location filename="../src/gdal/ogr_file_format.cpp" line="900"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="905"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="910"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="915"/>
        <location filename="../src/gdal/ogr_file_format.cpp" line="920"/>
        <source>Unable to load %n objects, reason: %1</source>
        <translation>
            <numerusform>Unable to load one object, reason: %1</numerusform>
            <numerusform>Unable to load %n objects, reason: %1</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OpenOrienteering::TagSelectWidget</name>
    <message numerus="yes">
        <location filename="../src/gui/map/map_find_feature.cpp" line="240"/>
        <source>%n object(s) selected</source>
        <translation>
            <numerusform>One object selected</numerusform>
            <numerusform>%n objects selected</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OpenOrienteering::TemplateTrack</name>
    <message numerus="yes">
        <location filename="../src/templates/template_track.cpp" line="573"/>
        <source>%n path object(s) could not be imported (reason: missing coordinates).</source>
        <translation>
            <numerusform>One path object could not be imported (reason: missing coordinates).</numerusform>
            <numerusform>%n path objects could not be imported (reason: missing coordinates).</numerusform>
        </translation>
    </message>
</context>
</TS>
